Learn R Programming

hsphase (version 3.0.0)

.ptr2por: Convert a two-row haplotype per individual to a one-row representation

Description

Converts a haplotype matrix where each individual is represented by two rows (allele 1 and allele 2) into a single-row-per-individual representation.

Usage

.ptr2por(haplotype)

Value

A matrix with one row per individual (allele 1 and allele 2 combined).

Arguments

haplotype

A matrix containing haplotypes with two rows per individual.