| aio | R Documentation |
Phasing of a single half-sib family group (single ordered chromosome).
aio(genotypeMatrix, bmh_forwardVectorSize = 30, bmh_excludeFP = TRUE,
bmh_nsap = 3, bmh_fillMissing = FALSE, output = "phase")
genotypeMatrix |
|
bmh_forwardVectorSize |
|
bmh_excludeFP |
|
bmh_nsap |
|
bmh_fillMissing |
|
output |
|
This function calls bmh, ssp, and phf.
If output = "phase", returns a haplotype matrix with two rows per individual (first paternal, second maternal),
coded as 0 (allele A), 1 (allele B), and 9 (missing/unphased).
Otherwise returns a list with elements:
phasedHalfsibs
sireHaplotype
blockStructure
Only this function needs to be called to phase a half-sib family. The genotype matrix must contain individuals from a single family and a single ordered chromosome.
bmh, ssp, phf
genotype <- matrix(c( # Define a Half-sib Genotype Matrix
2,1,0, # Individual 1
2,0,0, # Individual 2
0,0,2 # Individual 3
), byrow = TRUE, ncol = 3) # There are 3 individulas with three SNPs
aio(genotype) # The genotypes must include only one half-sib family and one chromosome
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.