co: Crossover Detection

View source: R/co.R

coR Documentation

Crossover Detection

Description

Detects possible crossover segments by comparing pairs of individuals in a half-sib family.

Usage

co(genotypeMatrix)

Arguments

genotypeMatrix

matrix. Half-sib genotypes (one individual per row; SNPs in columns ordered by map position). Genotypes must be numeric: 0, 1, 2 for AA, AB, BB and 9 for missing.

Value

A matrix Returns a matrix with the number of crossover events for each site.

Examples

genotype <- matrix(c(
  2,1,0,
  2,0,2,
  0,0,2
), byrow = TRUE, ncol = 3)

co(genotype)

hsphase documentation built on Feb. 17, 2026, 5:07 p.m.