dot-ptr2por: Convert a two-row haplotype per individual to a one-row...

.ptr2porR Documentation

Convert a two-row haplotype per individual to a one-row representation

Description

Converts a haplotype matrix where each individual is represented by two rows (allele 1 and allele 2) into a single-row-per-individual representation.

Usage

.ptr2por(haplotype)

Arguments

haplotype

A matrix containing haplotypes with two rows per individual.

Value

A matrix with one row per individual (allele 1 and allele 2 combined).


hsphase documentation built on Feb. 17, 2026, 5:07 p.m.