hh: Heatmap of Half-sibs

hhR Documentation

Heatmap of Half-sibs

Description

Creates a heatmap of a half-sib dataset using an opposing-homozygotes (OH) matrix, with optional sidebars showing inferred and/or real pedigree groupings.

Usage

hh(oh, inferredPedigree, realPedigree, pedOnly = TRUE)

Arguments

oh

matrix. Opposing-homozygotes matrix (e.g. output of ohg).

inferredPedigree

matrix. Inferred pedigree (e.g. output of rpoh).

realPedigree

matrix. Original pedigree.

pedOnly

logical. If TRUE, consider only individuals that exist in the real pedigree.

Value

Returns a heatmap of the OH matrix with sidebars color-coded by sire groups from the inferred and original pedigrees (where provided).

Author(s)

The function uses colors generated by the getcol function in the made4 package (Aedin Culhane).

See Also

ohg and rpoh

Examples

c1h1 <- .simulateHalfsib(numInd = 62, numSNP = 5000)
c1h2 <- .simulateHalfsib(numInd = 38, numSNP = 5000)
Genotype <- rbind(c1h1, c1h2)

oh <- ohg(Genotype)
hh(oh)

hsphase documentation built on Feb. 17, 2026, 5:07 p.m.