| hsphase-package | R Documentation |
Identification of recombination events, haplotype reconstruction and sire imputation using half-sib family SNP data.
| Package: | hsphase |
| Type: | Package |
| Version: | 3.0.0 |
| Date: | 2026-02-15 |
| License: | GPL-3 |
Main functions:
bmh: Block partitioning
ssp: Sire inference
aio: Phasing
imageplot: Image plot of the block structure
rpoh: Reconstruct pedigree based on opposing homozygotes
Auxiliary functions:
hss: Half-sib family splitter
cs: Chromosome splitter
para: Parallel data analysis
Mohammad H. Ferdosi mferdosi@une.udu.au, Cedric Gondro cgondro2@une.edu.au
Maintainer: Mohammad H. Ferdosi mhferdosi@yahoo.com
Ferdosi, M. H., Kinghorn, B. P., van der Werf, J. H., & Gondro, C. (2013).
Effect of genotype and pedigree error on detection of recombination events, sire imputation and haplotype inference using the hsphase algorithm.
In Proc. Assoc. Advmt. Anim. Breed. Genet (Vol. 20, pp. 546–549). AAABG; Napier, New Zealand.
Ferdosi, M. H., Kinghorn, B. P., van der Werf, J. H. J., & Gondro, C. (2014).
Detection of recombination events, haplotype reconstruction and imputation of sires using half-sib SNP genotypes.
Genetics Selection Evolution, 46(1), 11.
Ferdosi, M. H., Kinghorn, B. P., van der Werf, J. H. J., Lee, S. H., & Gondro, C. (2014).
hsphase: an R package for pedigree reconstruction, detection of recombination events, phasing and imputation of half-sib family groups.
BMC Bioinformatics, 15(1), 172.
Ferdosi, M. H., & Boerner, V. (2014).
A fast method for evaluating opposing homozygosity in large SNP data sets.
Livestock Science.
Sahoo S., Ferdosi M.H., van der Werf J.H.J., and de las Heras-Saldana S., et al. (2025) Proc. Assoc. Advmt. Anim. Breed. Genet. 26: 323
genotype <- matrix(c(
0,0,0,0,1,2,2,2,0,0,2,0,0,0,
2,2,2,2,1,0,0,0,2,2,2,2,2,2,
2,2,2,2,1,2,2,2,0,0,2,2,2,2,
2,2,2,2,0,0,0,0,2,2,2,2,2,2,
0,0,0,0,0,2,2,2,2,2,2,0,0,0
), ncol = 14, byrow = TRUE)
ssp(bmh(genotype), genotype)
aio(genotype)
imageplot(bmh(genotype), title = "ImagePlot example")
rplot(genotype, 1:14)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.