| imageplot | R Documentation |
Create an image plot of the blocking structure.
imageplot(x, title = c(), rv = FALSE, ...)
x |
|
title |
|
rv |
|
... |
Optional graphical parameters. |
White indicates regions of unknown origin; red and blue correspond to the two sire strands.
This is a modified version of a function written by Chris Seidel, available at http://www.phaget4.org/R/image_matrix.html.
bmh, aio
genotype <- matrix(c(
0,2,1,1,1,
2,0,1,2,2,
2,2,1,0,2,
2,2,1,1,1,
0,0,2,1,0
), ncol = 5, byrow = TRUE)
imageplot(bmh(genotype))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.