View source: R/namingInferedPedigree.R
| pedigreeNaming | R Documentation |
Tries to link the inferred pedigree from rpoh with sire IDs in the original pedigree and fix pedigree errors.
pedigreeNaming(inferredPedigree, realPedigree)
inferredPedigree |
|
realPedigree |
|
This function calls bmh and recombinations to count the number of recombinations in each half-sib group.
Returns the inferred pedigree with the best match to sire names used in the original pedigree file.
rpoh and ohg
# Please run demo(hsphase)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.