| pm | R Documentation |
Creates a recombination (probability) matrix based on the blocking structure.
pm(blockMatrix, method = "constant")
blockMatrix |
|
method |
|
This function identifies recombination between two consecutive sites and marks recombination sites with 1.
If there are unknown sites between two blocks, it marks these sites with:
1 for the "constant" method, or
1 / m for the "relative" method, where m is the number of unknown sites.
genotype <- matrix(c(
0,2,0,1,0,
2,0,1,2,2,
2,2,1,0,2,
2,2,1,1,1,
0,0,2,1,0
), ncol = 5, byrow = TRUE)
block <- bmh(genotype)
pm(block)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.