recombinations: Recombination Number

View source: R/hsphase.R

recombinationsR Documentation

Recombination Number

Description

Counts the number of recombinations for each individual based on the block structure.

Usage

recombinations(blockMatrix)

Arguments

blockMatrix

matrix. Block structure (output of bmh).

Value

A numeric vector of recombination counts with length equal to the number of individuals (rows) in blockMatrix.

See Also

bmh

Examples

genotype <- matrix(c(
  2,1,0,0,
  2,0,2,2,
  0,0,2,2,
  0,2,0,0
), byrow = TRUE, ncol = 4)

recombinations(bmh(genotype))

hsphase documentation built on Feb. 17, 2026, 5:07 p.m.