Converts a haplotype matrix where each individual is represented by one row and alleles are stored in alternating columns (1st allele, 2nd allele, ...) into a two-row-per-individual representation.
.o2tH(haplotype)An integer matrix in a two-row-per-individual format with
2 * nrow(haplotype) rows and ncol(haplotype) / 2 columns.
Row names are interleaved using the original individual names.
A haplotype object:
a matrix with individuals in rows and allele columns in pairs
(i.e. ncol(haplotype) must be even).
Internally, any allele code of `2` is converted to `0` before conversion.