powered by
Converts a haplotype matrix where each individual is represented by two rows (allele 1 and allele 2) into a single-row-per-individual representation.
.ptr2por(haplotype)
A matrix with one row per individual (allele 1 and allele 2 combined).
A matrix containing haplotypes with two rows per individual.