| bmh | R Documentation |
Identifies the block structure (chromosome segments) in a half-sib family that each individual inherited from its sire.
bmh(
GenotypeMatrix,
forwardVectorSize = 30,
excludeFP = TRUE,
nsap = 3,
fillMissing = FALSE
)
GenotypeMatrix |
|
forwardVectorSize |
|
excludeFP |
|
nsap |
|
fillMissing |
|
A matrix of block structure containing 1, 2, and 0.
Values 1 and 2 represent the two sire strands (arbitrary labeling within a chromosome),
and 0 indicates unknown origin.
The genotype matrix must contain individuals from only one half-sib family and one ordered chromosome.
ssp, phf, aio, imageplot
genotype <- matrix(c(
0,2,1,1,1,
2,0,1,2,2,
2,2,1,0,2,
2,2,1,1,1,
0,0,2,1,0
), ncol = 5, byrow = TRUE)
bmh(genotype)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.