| co | R Documentation |
Detects possible crossover segments by comparing pairs of individuals in a half-sib family.
co(genotypeMatrix)
genotypeMatrix |
|
A matrix Returns a matrix with the number of crossover events for each site.
genotype <- matrix(c(
2,1,0,
2,0,2,
0,0,2
), byrow = TRUE, ncol = 3)
co(genotype)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.