| .ptr2por | R Documentation |
Converts a haplotype matrix where each individual is represented by two rows (allele 1 and allele 2) into a single-row-per-individual representation.
.ptr2por(haplotype)
haplotype |
A matrix containing haplotypes with two rows per individual. |
A matrix with one row per individual (allele 1 and allele 2 combined).
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.