| hbp | R Documentation |
Creates a block-structure matrix for a half-sib family based on phased data of the sire and the half-sib family.
hbp(PhasedGenotypeMatrix, PhasedSireGenotype, strand = "auto")
PhasedGenotypeMatrix |
|
PhasedSireGenotype |
|
strand |
|
A matrix in which 3 or 4 indicates the SNP originates from, respectively, sire strand 1 or strand 2.
0 indicates the origin is unknown.
The input matrices must contain individuals from a single half-sib family and a single ordered chromosome. The SNP order must match between inputs.
aio, ssp
sire <- matrix(c(
0,0,0,0,0,1, # Haplotype one of the sire
0,1,1,1,1,0 # Haplotype two of the sire
), byrow = TRUE, ncol = 6)
haplotypeHalfsib <- matrix(c(
1,0,1,1,1,1, # Individual one, haplotype one
0,1,0,0,0,0, # Individual one, haplotype two
0,1,1,0,1,1, # Individual two, haplotype one
1,0,0,1,0,0 # Individual two, haplotype two
), byrow = TRUE, ncol = 6) # 0s and 1s are alelle a and b
hbp(haplotypeHalfsib, sire)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.