| hh | R Documentation |
Creates a heatmap of a half-sib dataset using an opposing-homozygotes (OH) matrix, with optional sidebars showing inferred and/or real pedigree groupings.
hh(oh, inferredPedigree, realPedigree, pedOnly = TRUE)
oh |
|
inferredPedigree |
|
realPedigree |
|
pedOnly |
|
Returns a heatmap of the OH matrix with sidebars color-coded by sire groups from the inferred and original pedigrees (where provided).
The function uses colors generated by the getcol function in the made4 package (Aedin Culhane).
ohg and rpoh
c1h1 <- .simulateHalfsib(numInd = 62, numSNP = 5000)
c1h2 <- .simulateHalfsib(numInd = 38, numSNP = 5000)
Genotype <- rbind(c1h1, c1h2)
oh <- ohg(Genotype)
hh(oh)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.