| ohd | R Documentation |
Counts, for each animal, the number of loci where it contributes opposing homozygotes in sites that imply heterozygosity in the sire.
ohd(genotypeMatrix, unique_check = FALSE, SNPs = 6000)
genotypeMatrix |
|
unique_check |
|
SNPs |
|
A numeric vector with the number of heterozygous sites that each sample caused.
This function can be used to identify pedigree errors; i.e., outliers with unusually high values.
This method was suggested by Bruce Tier <btier@une.edu.au> to identify pedigree errors.
genotype <- matrix(c(
2,1,0,
2,0,0,
0,0,2
), byrow = TRUE, ncol = 3)
ohd(genotype)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.