| ohg | R Documentation |
Creates a matrix of pairwise opposing-homozygote (OH) counts from a genotype matrix.
ohg(genotypeMatrix)
genotypeMatrix |
|
Returns a square matrix (sample \times sample) of pairwise counts of opposing homozygotes.
(Some versions may return this matrix inside a named list element.)
This function can be slow for large datasets.
Ferdosi, M. H., & Boerner, V. (2014). A fast method for evaluating opposing homozygosity in large SNP data sets. Livestock Science.
rpoh
genotype <- matrix(c(
2,1,0,
2,0,0,
0,0,2
), byrow = TRUE, ncol = 3)
ohg(genotype)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.