| phf | R Documentation |
Phases a half-sib family using the block structure and an imputed sire haplotype matrix.
phf(GenotypeMatrix, blockMatrix, sirePhasedMatrix)
GenotypeMatrix |
|
blockMatrix |
|
sirePhasedMatrix |
|
Returns a matrix containing the phased parental haplotypes of the half-sibs (two rows per individual).
Alleles are coded as 0 (A), 1 (B), and 9 (missing/unphased).
The genotype matrix must contain individuals from one half-sib family and one ordered chromosome.
This function is used by aio for complete phasing of a half-sib group.
aio
genotype <- matrix(c(
2,1,0,
2,0,0,
0,0,2
), byrow = TRUE, ncol = 3)
block <- bmh(genotype)
phf(genotype, block, ssp(block, genotype))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.