| recombinations | R Documentation |
Counts the number of recombinations for each individual based on the block structure.
recombinations(blockMatrix)
blockMatrix |
|
A numeric vector of recombination counts with length equal to the number of individuals (rows) in blockMatrix.
bmh
genotype <- matrix(c(
2,1,0,0,
2,0,2,2,
0,0,2,2,
0,2,0,0
), byrow = TRUE, ncol = 4)
recombinations(bmh(genotype))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.