Learn R Programming

hsphase (version 3.0.0)

recombinations: Recombination Number

Description

Counts the number of recombinations for each individual based on the block structure.

Usage

recombinations(blockMatrix)

Value

A numeric vector of recombination counts with length equal to the number of individuals (rows) in blockMatrix.

Arguments

blockMatrix

matrix. Block structure (output of bmh).

See Also

bmh

Examples

Run this code
genotype <- matrix(c(
  2,1,0,0,
  2,0,2,2,
  0,0,2,2,
  0,2,0,0
), byrow = TRUE, ncol = 4)

recombinations(bmh(genotype))

Run the code above in your browser using DataLab