| ssp | R Documentation |
Infers (imputes) and phases the sire haplotypes based on the block structure matrix and homozygous sites of the half-sib genotype matrix.
ssp(blockMatrix, genotypeMatrix)
blockMatrix |
|
genotypeMatrix |
|
A matrix with two rows (one per sire haplotype) and columns corresponding to SNPs in genotype order.
Alleles are coded as 0 (A) and 1 (B). Alleles that could not be imputed are coded as 9.
phf, aio, imageplot
genotype <- matrix(c(
0,2,1,1,1,
2,0,1,2,2,
2,2,1,0,2,
2,2,1,1,1,
0,0,2,1,0
), ncol = 5, byrow = TRUE)
ssp(bmh(genotype), genotype)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.