View source: R/switchDetector.R
| switchDetector | R Documentation |
Detect switch errors in the haplotypes of a half-sib family.
switchDetector(groupMatrix)
groupMatrix |
|
A list of integer vectors. The list length equals the number of individuals.
Each vector contains the locations of detected switch errors for that individual.
groupMatSingle
haplotype <- .simulateHalfsib(8, 3000, type = "haplotype")$phased
switches <- list(2500,0,0,1200,c(1000,2000),500,2000,0)
haplotype2 <- addSwitch(haplotype, switches, 0)
gMat <- groupMatSingle(haplotype2, 100, 2, "haplotype")
switchDetector(gMat)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.